@@ -5,7 +5,7 @@ DROP DATABASE IF EXISTS regression_sort;
 CREATE DATABASE regression_sort WITH TEMPLATE = template0 ENCODING='SQL_ASCII' LC_COLLATE='C' LC_CTYPE='C';
 \c regression_sort
 SET client_min_messages = error;
-\i orafce.sql
+CREATE EXTENSION orafce;
 SET client_min_messages = default;
 CREATE TABLE test_sort (name TEXT);
 INSERT INTO test_sort VALUES ('red'), ('brown'), ('yellow'), ('Purple');
